Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(833)

Unified Diff: components/autofill/core/common/password_form.h

Issue 1723583004: CREDENTIAL: Convert federations from URLs to origins throughout. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: iOS2 Created 4 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: components/autofill/core/common/password_form.h
diff --git a/components/autofill/core/common/password_form.h b/components/autofill/core/common/password_form.h
index 5f34a671af2c896e39143d929aadab8a1a0d8410..4e9644e5be4c942ea2940b321be5b77e1672fd93 100644
--- a/components/autofill/core/common/password_form.h
+++ b/components/autofill/core/common/password_form.h
@@ -13,6 +13,7 @@
#include "base/time/time.h"
#include "components/autofill/core/common/form_data.h"
#include "url/gurl.h"
+#include "url/origin.h"
namespace autofill {
@@ -245,8 +246,8 @@ struct PasswordForm {
// (i.e in PasswordSpecificsData). Rename these occurrences.
GURL icon_url;
- // The URL of identity provider used for federated login.
- GURL federation_url;
+ // The origin of identity provider used for federated login.
+ url::Origin federation_origin;
// If true, Chrome will not return this credential to a site in response to
// 'navigator.credentials.request()' without user interaction.

Powered by Google App Engine
This is Rietveld 408576698